pub struct MempoolNodeConfig {
pub log_truncate_long_values: bool,
pub emit_stats_metrics: bool,
pub clean_db_period_rounds: NonZeroU16,
pub cache_future_broadcasts_rounds: u16,
pub max_blocking_tasks: NonZeroU16,
pub max_upload_tasks: NonZeroU8,
pub max_download_tasks: NonZeroU16,
}Fields
log_truncate_long_values: booltrue to truncate hashes, signatures and use non-standard format for large structs
that may be more readable
emit_stats_metrics: booltrue to export metrics on how the current node views every other’s points,
this is NxN amount of metrics (N labels from each of N nodes)
clean_db_period_rounds: NonZeroU16How often (in rounds) delete obsolete data and trigger rocksDB compaction.
cache_future_broadcasts_rounds: u16amount of future [Round]s (beyond current Dag)
that BroadcastFilter caches
to extend Dag without downloading points
max_blocking_tasks: NonZeroU16Tokio default upper limit is 512.
Tycho tread pool config
does not have a corresponding parameter and does not change tokio’s default value.
max_upload_tasks: NonZeroU8Max simultaneous point search tasks fulfilling download request
max_download_tasks: NonZeroU16Limits amount of unique points being simultaneously downloaded from all peers.